@@ -1,7 +1,7 @@
 
 #   IGraph R package
-#   Copyright (C) 2005  Gabor Csardi <csardi@rmki.kfki.hu>
-#   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+#   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
+#   334 Harvard street, Cambridge, MA 02139 USA
 #   
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -25,16 +25,28 @@ cocitation <- function(graph, v=V(graph)) {
   if (!is.igraph(graph)) {
     stop("Not a graph object")
   }
+  v <- as.igraph.vs(graph, v)
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_cocitation", graph, as.igraph.vs(graph, v),
-        PACKAGE="igraph")
+  res <- .Call("R_igraph_cocitation", graph, v-1,
+               PACKAGE="igraph")
+  if (getIgraphOpt("add.vertex.names") && is.named(graph)) {
+    rownames(res) <- get.vertex.attribute(graph, "name", v)
+    colnames(res) <- get.vertex.attribute(graph, "name")
+  }
+  res
 }
 
 bibcoupling <- function(graph, v=V(graph)) {
   if (!is.igraph(graph)) {
     stop("Not a graph object")
   }
+  v <- as.igraph.vs(graph, v)
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_bibcoupling", graph, as.igraph.vs(graph, v),
-        PACKAGE="igraph")
+  res <- .Call("R_igraph_bibcoupling", graph, v-1,
+               PACKAGE="igraph")
+  if (getIgraphOpt("add.vertex.names") && is.named(graph)) {
+    rownames(res) <- get.vertex.attribute(graph, "name", v)
+    colnames(res) <- get.vertex.attribute(graph, "name")
+  }
+  res
 }
