@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2007  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2007-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard street, Cambridge, MA 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,14 +30,15 @@ int main() {
   igraph_t g;
   igraph_vector_t v, weights;
   long int i;
-  igraph_integer_t value, retcode;
+  igraph_real_t value;
   igraph_arpack_options_t options;
   
   igraph_star(&g, 100, IGRAPH_STAR_UNDIRECTED, 0);
 
   igraph_arpack_options_init(&options);
   igraph_vector_init(&v, 0);
-  igraph_eigenvector_centrality(&g, &v, &value, /*scale=*/0, /*weights=*/0, 
+  igraph_eigenvector_centrality(&g, &v, &value, /*directed=*/ 0, 
+				/*scale=*/0, /*weights=*/0, 
 				&options);
 
   if (options.info != 0) {
@@ -53,8 +54,8 @@ int main() {
 
   /* Special cases: check for empty graph */
   igraph_empty(&g, 10, 0);
-  igraph_eigenvector_centrality(&g, &v, &value, 0, 0, &options);
-  if (igraph_finite(value)) {
+  igraph_eigenvector_centrality(&g, &v, &value, 0, 0, 0, &options);
+  if (value != 0.0) {
     return 1;
   }
   for (i=0; i<igraph_vector_size(&v); i++) {
@@ -67,9 +68,9 @@ int main() {
   igraph_full(&g, 10, 0, 0);
   igraph_vector_init(&weights, 45);
   igraph_vector_fill(&weights, 0);
-  igraph_eigenvector_centrality(&g, &v, &value, 0, &weights, &options);
+  igraph_eigenvector_centrality(&g, &v, &value, 0, 0, &weights, &options);
   igraph_vector_destroy(&weights);
-  if (igraph_finite(value)) {
+  if (value != 0.0) {
     return 2;
   }
   for (i=0; i<igraph_vector_size(&v); i++) {
