@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard street, Cambridge, MA 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ int main() {
 
   igraph_vector_init(&v2, 0);
   igraph_get_edgelist(&g2, &v2, 0);
-  if (!igraph_vector_is_equal(&v1, &v2)) {
+  if (!igraph_vector_all_e(&v1, &v2)) {
     return 1;
   }
 
