@@ -36,9 +36,8 @@ void print_set(igraph_set_t *set, FILE *f) {
 
 int main() {
   
-  igraph_set_t set, set2;
+  igraph_set_t set;
   int i;
-  igraph_integer_t *ptr;
 
   /* simple init */
   igraph_set_init(&set, 0);
