@@ -23,7 +23,7 @@
 
 #include <igraph.h>
 
-int strvector_print(const igraph_strvector_t *sv) {
+void strvector_print(const igraph_strvector_t *sv) {
   long int i, s=igraph_strvector_size(sv);
   for (i=0; i<s; i++) {
     printf("---%s---\n", STR(*sv, i));
@@ -33,7 +33,7 @@ int strvector_print(const igraph_strvector_t *sv) {
 int main() {
 
   igraph_strvector_t sv1, sv2;
-  char *str1, *str2;
+  char *str1;
   int i;
 
   /* igraph_strvector_init, igraph_strvector_destroy */
