@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard st, Cambridge MA, 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,11 +30,23 @@ int main() {
   
   igraph_vector_init_int(&v, 2, 5, 5);
   igraph_lattice(&g, &v, 1, IGRAPH_DIRECTED, 1 /*mutual*/, 0 /*circular*/);
-  igraph_to_undirected(&g, IGRAPH_TO_UNDIRECTED_COLLAPSE);
+  igraph_to_undirected(&g, IGRAPH_TO_UNDIRECTED_COLLAPSE, 
+		       /*edge_comb=*/ 0);
   igraph_write_graph_edgelist(&g, stdout);
 
   igraph_destroy(&g);
   igraph_vector_destroy(&v);
+
+  printf("---\n");
+
+  igraph_small(&g, 10, IGRAPH_DIRECTED, 
+	       0,1, 2,1, 2,3, 2,3, 4,3, 4,3,
+	       5,6, 6,5, 6,7, 6,7, 7,6, 7,8, 7,8, 8,7, 8,7, 8,8, 9,9, 9,9,
+	       -1);
+  igraph_to_undirected(&g, IGRAPH_TO_UNDIRECTED_MUTUAL,
+		       /*edge_comb=*/ 0);
+  igraph_write_graph_edgelist(&g, stdout);
+  igraph_destroy(&g);
   
   return 0;
 }
