@@ -26,9 +26,9 @@
 int main() {
 
   igraph_t g;
-  const igraph_vector_t v=IGRAPH_VECTOR_NULL;
+  igraph_vector_t v=IGRAPH_VECTOR_NULL;
   igraph_real_t edges[] = { 0,1, 1,2, 2,2, 2,3, 2,4, 3,4 };
-  igraph_vector_t v2, v3;
+  igraph_vector_t v2;
   long int i;
   igraph_vit_t vit;
   igraph_vs_t vs;
