@@ -27,7 +27,7 @@ int main() {
   igraph_t g;
   igraph_real_t  modularity, temperature;
   igraph_vector_t membership, csize;
-  long int i;
+  /* long int i; */
   igraph_real_t cohesion, adhesion;
   igraph_integer_t inner_links;
   igraph_integer_t outer_links;
